==> 3.5.12-core.tar: kdepim/kdgantt/KDGanttViewTaskItem.h <==
/* -*- Mode: C++ -*-
   $Id: KDGanttViewTaskItem.h 1158452 2010-08-02 19:28:10Z tpearson $
   KDGantt - a multi-platform charting engine
*/

/****************************************************************************
 ** Copyright (C)  2002-2004 Klarlvdalens Datakonsult AB.  All rights reserved.
 **
 ** This file is part of the KDGantt library.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
 ** Licensees holding valid commercial KDGantt licenses may use this file in
 ** accordance with the KDGantt Commercial License Agreement provided with
 ** the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.klaralvdalens-datakonsult.se/Public/products/ for
 **   information about KDGantt Commercial License Agreements.
 **
 ** Contact info@klaralvdalens-datakonsult.se if any conditions of this
 ** licensing are not clear to you.
 **
 ** As a special exception, permission is given to link this program
 ** with any edition of Qt, and distribute the resulting executable,
 ** without including the source code for Qt in the source distribution.
 **
 **********************************************************************/


#ifndef KDGANTTVIEWTASKITEM_H
#define KDGANTTVIEWTASKITEM_H

#include "KDGanttViewItem.h"
class KDCanvasRectangle;
class TQBrush;

class KDGanttViewTaskItem : public KDGanttViewItem
{
public:
    KDGanttViewTaskItem( KDGanttView* view,
                            const TQString& lvtext = TQString::null,
                            const TQString& name = TQString::null );
    KDGanttViewTaskItem( KDGanttViewItem* parent,
                            const TQString& lvtext = TQString::null,
                            const TQString& name = TQString::null );
    KDGanttViewTaskItem( KDGanttView* view, KDGanttViewItem* after,
                            const TQString& lvtext = TQString::null,
                            const TQString& name = TQString::null );
    KDGanttViewTaskItem( KDGanttViewItem* parent, KDGanttViewItem* after,
                            const TQString& lvtext = TQString::null,
                            const TQString& name = TQString::null );
    virtual ~KDGanttViewTaskItem();

    void setStartTime( const TQDateTime& start );
    void setEndTime( const TQDateTime& end );

protected:
    void showItem( bool show = true, int coordY = 0 );

private:
    void initItem();
    void hideMe();
    TQBrush myBrush, undefinedBrush;
    bool _showUndefinedBrush;
};

#endif

==> 3.5.13-core.tar: kdepim/kdgantt/KDGanttViewTaskItem.h <==
/* -*- Mode: C++ -*-
   $Id: KDGanttViewTaskItem.h 1246260 2011-08-10 22:19:39Z tpearson $
   KDGantt - a multi-platform charting engine
*/

/****************************************************************************
 ** Copyright (C)  2002-2004 Klarlvdalens Datakonsult AB.  All rights reserved.
 **
 ** This file is part of the KDGantt library.
 **
 ** This file may be distributed and/or modified under the terms of the
 ** GNU General Public License version 2 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
 ** packaging of this file.
 **
 ** Licensees holding valid commercial KDGantt licenses may use this file in
 ** accordance with the KDGantt Commercial License Agreement provided with
 ** the Software.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ** See http://www.klaralvdalens-datakonsult.se/Public/products/ for
 **   information about KDGantt Commercial License Agreements.
 **
 ** Contact info@klaralvdalens-datakonsult.se if any conditions of this
 ** licensing are not clear to you.
 **
 ** As a special exception, permission is given to link this program
 ** with any edition of TQt, and distribute the resulting executable,
 ** without including the source code for TQt in the source distribution.
 **
 **********************************************************************/


#ifndef KDGANTTVIEWTASKITEM_H
#define KDGANTTVIEWTASKITEM_H

#include "KDGanttViewItem.h"
class KDCanvasRectangle;
class TQBrush;

class KDGanttViewTaskItem : public KDGanttViewItem
{
public:
    KDGanttViewTaskItem( KDGanttView* view,
                            const TQString& lvtext = TQString(),
                            const TQString& name = TQString() );
    KDGanttViewTaskItem( KDGanttViewItem* parent,
                            const TQString& lvtext = TQString(),
                            const TQString& name = TQString() );
    KDGanttViewTaskItem( KDGanttView* view, KDGanttViewItem* after,
                            const TQString& lvtext = TQString(),
                            const TQString& name = TQString() );
    KDGanttViewTaskItem( KDGanttViewItem* parent, KDGanttViewItem* after,
                            const TQString& lvtext = TQString(),
                            const TQString& name = TQString() );
    virtual ~KDGanttViewTaskItem();

    void setStartTime( const TQDateTime& start );
    void setEndTime( const TQDateTime& end );

protected:
    void showItem( bool show = true, int coordY = 0 );

private:
    void initItem();
    void hideMe();
    TQBrush myBrush, undefinedBrush;
    bool _showUndefinedBrush;
};

#endif
